@@ -1,11 +1,11 @@
 #pragma once
-#define GIT_COMMIT_HASH    "967c3c7404d4fa00234e29c70df3e263386d2597"
-#define GIT_BRANCH         "v0.52.1"
-#define GIT_COMMIT_MESSAGE "version: bump to 0.52.1"
-#define GIT_COMMIT_DATE    "Sun Nov 9 23:31:36 2025"
+#define GIT_COMMIT_HASH    "386376400119dd46a767c9f8c8791fd22c7b6e61"
+#define GIT_BRANCH         "v0.52.2"
+#define GIT_COMMIT_MESSAGE "[gha] Nix: update inputs"
+#define GIT_COMMIT_DATE    "Wed Dec 3 22:59:30 2025"
 #define GIT_DIRTY          "clean"
-#define GIT_TAG            "v0.52.1"
-#define GIT_COMMITS        "6564"
+#define GIT_TAG            "v0.52.2"
+#define GIT_COMMITS        "6581"
 
 #define AQUAMARINE_VERSION "0.10.0"
 // clang-format off
@@ -13,7 +13,7 @@
 #define AQUAMARINE_VERSION_MINOR 10
 #define AQUAMARINE_VERSION_PATCH 0
 // clang-format on
-#define HYPRLANG_VERSION     "0.6.6"
+#define HYPRLANG_VERSION     "0.6.7"
 #define HYPRUTILS_VERSION    "0.10.4"
 #define HYPRCURSOR_VERSION   "0.1.13"
 #define HYPRGRAPHICS_VERSION "0.4.0"
